AirTrafficSim is a lightweight collection of tools for air traffic management research.

This branch (`v0.2`) contains the rewrite of the older `v0.1`[^1] version.

[^1]: The latest commit can be viewed [here](https://github.com/HKUST-OCTAD-LAB/AirTrafficSim/commit/7a3c3249e602ad17c4b27c7bf900e571d9f7feea). It is considered deprecated and will not receieve futher updates.